@@ -572,6 +572,16 @@ JobRouter::EvalAllSrcJobPeriodicExprs()
 	while(m_jobs.iterate(job))
 	{
 		orig_ad = ad_collection->GetClassAd(job->src_key);
+		// Forward any update of TimerRemove from the source schedd's
+		// job ad to our other copy of the ad.
+		// This brute-force update assumes that if  TimerRemove initially
+		// evaluates to an integer, it will continue to do so throughout
+		// the job's life.
+		int timer_remove = -1;
+		if (orig_ad->EvaluateAttrInt(ATTR_TIMER_REMOVE_CHECK, timer_remove)) {
+			job->src_ad.InsertAttr(ATTR_TIMER_REMOVE_CHECK, timer_remove);
+			job->src_ad.MarkAttributeClean(ATTR_TIMER_REMOVE_CHECK);
+		}
 		if (false == EvalSrcJobPeriodicExpr(job))
 		{
 			dprintf(D_ALWAYS, "JobRouter failure (%s): Unable to "
@@ -580,7 +590,7 @@ JobRouter::EvalAllSrcJobPeriodicExprs()
 			if( !orig_ad ) {
 				dprintf(D_ALWAYS, "JobRouter failure (%s): "
 					"failed to reset src job "
-					"attributes, because ad not found"
+					"attributes, because ad not found "
 					"in collection.\n",job->JobDesc().c_str());
 				continue;
 			}
